# beaker-pysb

[![PyPI - Version](https://img.shields.io/pypi/v/beaker-pysb.svg)](https://pypi.org/project/beaker-pysb)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/beaker-pysb.svg)](https://pypi.org/project/beaker-pysb)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install beaker-pysb
```

## Docker quickstart

```
export OPENAI_API_KEY=your OpenAI key goes here
docker-compose up --build
```

## License

`beaker-pysb` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
